==> haskell-hspec-wai-json-0.9.0-55-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.0
id: hspec-wai-json-0.9.0-8rF9u3nk32AFYcELtcMxhU
key: hspec-wai-json-0.9.0-8rF9u3nk32AFYcELtcMxhU
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
abi: cb70e4ffa33ca39956c777df3d341347
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-json-0.9.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-json-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hspec-wai-json-0.9.0
hs-libraries: HShspec-wai-json-0.9.0-8rF9u3nk32AFYcELtcMxhU
depends:
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF
    aeson-qq-0.8.2-3y0CvzJvBv2LJOMktMwjMO base-4.10.1.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    hspec-wai-0.9.0-EGTpf7FtWDXHu0BSpZljlJ template-haskell-2.12.0.0
abi-depends: aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             aeson-qq-0.8.2-3y0CvzJvBv2LJOMktMwjMO=3fac704c2698ab848a26c067889969ea
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             hspec-wai-0.9.0-EGTpf7FtWDXHu0BSpZljlJ=a64e7840d2d8796569589d3263af915c
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.9.0-57-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.0
id: hspec-wai-json-0.9.0-27NpS5IHICpl2TLslV3nG
key: hspec-wai-json-0.9.0-27NpS5IHICpl2TLslV3nG
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
abi: 0d4684764e339455956fa38d2f7c3e53
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-json-0.9.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-wai-json-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hspec-wai-json-0.9.0
hs-libraries: HShspec-wai-json-0.9.0-27NpS5IHICpl2TLslV3nG
depends:
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF
    aeson-qq-0.8.2-6MWmZEOGZnp7J90sg4hKme base-4.10.1.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR
    hspec-wai-0.9.0-HMGRQUq1NuI2HoOob7CToe template-haskell-2.12.0.0
abi-depends: aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             aeson-qq-0.8.2-6MWmZEOGZnp7J90sg4hKme=73595c181d3d72e7570dca59aba5fe4c
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             case-insensitive-1.2.0.11-6moQBu1HxUPLo5Vi55MiZR=1c6594e3192e08eeeeb5e70e5d90ad4f
             hspec-wai-0.9.0-HMGRQUq1NuI2HoOob7CToe=7c0462a328926289bf808f7516efc27a
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
